#jinja2: trim_blocks: False
include "/etc/rndc.key";
options {
        listen-on port {{ designate_bind_port }} { {{ 'api' | kolla_address }}; };
        {% if api_interface != dns_interface %}
        listen-on port {{ designate_bind_port }} { {{ 'dns' | kolla_address }}; };
        {% endif %}
        directory       "/var/lib/named";
        allow-new-zones yes;
        dnssec-validation {{ designate_dnssec_validation }};
        auth-nxdomain no;
        request-ixfr no;
        recursion {{ designate_recursion }};
        {% if designate_forwarders_addresses %}
        forwarders { {{ designate_forwarders_addresses }}; };
        {% endif %}
        minimal-responses yes;
        allow-notify { {% for host in groups['designate-worker'] %}{{ 'api' | kolla_address(host) }};{% endfor %} };
};

controls {
        inet {{ 'api' | kolla_address }} port {{ designate_rndc_port }} allow { {% for host in groups['designate-worker'] %}{{ 'api' | kolla_address(host) }}; {% endfor %} } keys { "rndc-key"; };
};
