modules:
  http_2xx:
    prober: http
  os_endpoint:
    prober: http
    http:
      valid_status_codes: [200,300]
      headers:
        Content-Type: application/json
      fail_if_body_not_matches_regexp:
        - "versions"
  http_post_2xx:
    prober: http
    http:
      method: POST
  tcp_connect:
    prober: tcp
  tls_connect:
    prober: tcp
    tcp:
      tls: true
  ssh_banner:
    prober: tcp
    tcp:
      query_response:
      - expect: "^SSH-2.0-"
  icmp:
    prober: icmp
