[
  {kernel, [
    {inet_dist_use_interface, {% raw %}{{% endraw %}{{ api_interface_address | put_address_in_context('rabbitmq') }}}},
    {inet_dist_listen_min, {{ role_rabbitmq_cluster_port }}},
    {inet_dist_listen_max, {{ role_rabbitmq_cluster_port }}}
  ]}
].
