{% set vitrage_log_dir = '/var/log/kolla/vitrage' %}
Listen {{ 'api' | kolla_address | put_address_in_context('url') }}:{{ vitrage_api_port }}

ServerSignature Off
ServerTokens Prod
TraceEnable off
TimeOut {{ kolla_httpd_timeout }}
KeepAliveTimeout {{ kolla_httpd_keep_alive }}

ErrorLog "{{ vitrage_log_dir }}/apache-error.log"
<IfModule log_config_module>
    CustomLog "{{ vitrage_log_dir }}/apache-access.log" common
</IfModule>

{% if vitrage_logging_debug | bool %}
LogLevel info
{% endif %}

<VirtualHost *:{{ vitrage_api_port }}>

  ## Vhost docroot
  DocumentRoot "/var/www/cgi-bin/vitrage"

  ## Directories, there should at least be a declaration for /var/www/cgi-bin/vitrage

  <Directory "/var/www/cgi-bin/vitrage">
    Options Indexes FollowSymLinks MultiViews
    AllowOverride None
    Require all granted
  </Directory>

  ## Logging
  ErrorLog "{{ vitrage_log_dir }}/vitrage_wsgi_error.log"
  ServerSignature Off
  CustomLog "{{ vitrage_log_dir }}/vitrage_wsgi_access.log" combined
  WSGIApplicationGroup %{GLOBAL}
  WSGIDaemonProcess vitrage group=vitrage processes={{ vitrage_api_workers }} threads=1 user=vitrage
  WSGIProcessGroup vitrage
  WSGIScriptAlias / "/var/www/cgi-bin/vitrage/app.wsgi"
{% if enable_vitrage_prometheus_datasource | bool %}
  WSGIPassAuthorization On
{% endif %}
</VirtualHost>
