{
    "command": "/opt/prometheus_alertmanager/alertmanager --config.file=/etc/prometheus/alertmanager.yml --web.listen-address={{ api_interface_address | put_address_in_context('url') }}:{{ prometheus_alertmanager_port }} --web.external-url={{ prometheus_alertmanager_external_url }} --cluster.listen-address={% if groups["prometheus-alertmanager"] | length > 1 %}{{ api_interface_address | put_address_in_context('url') }}:{{ prometheus_alertmanager_cluster_port }} {% for host in groups["prometheus-alertmanager"] %} --cluster.peer={{ 'api' | kolla_address(host) | put_address_in_context('url') }}:{{ hostvars[host]['prometheus_alertmanager_cluster_port'] }}{% endfor %}{% endif %} --storage.path /var/lib/prometheus",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/prometheus-alertmanager.yml",
            "dest": "/etc/prometheus/alertmanager.yml",
            "owner": "prometheus",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/*.tmpl",
            "dest": "/etc/prometheus/",
            "optional": true,
            "owner": "prometheus",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/data",
            "owner": "prometheus:kolla",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/prometheus",
            "owner": "prometheus:kolla",
            "recurse": true
        }
    ]
}
