{
    "command": "neutron-server --config-file /etc/neutron/neutron.conf {% if neutron_plugin_agent in ['openvswitch', 'linuxbridge', 'ovn'] %} --config-file /etc/neutron/plugins/ml2/ml2_conf.ini --config-file /etc/neutron/neutron_vpnaas.conf {% elif neutron_plugin_agent in ['vmware_nsxv', 'vmware_nsxv3', 'vmware_nsxp', 'vmware_dvs'] %} --config-file /etc/neutron/plugins/vmware/nsx.ini {% endif %}",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/neutron.conf",
            "dest": "/etc/neutron/neutron.conf",
            "owner": "neutron",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/neutron_vpnaas.conf",
            "dest": "/etc/neutron/neutron_vpnaas.conf",
            "owner": "neutron",
            "perm": "0600"
        },
        {% if neutron_policy_file is defined %}{
            "source": "{{ container_config_directory }}/{{ neutron_policy_file }}",
            "dest": "/etc/neutron/{{ neutron_policy_file }}",
            "owner": "neutron",
            "perm": "0600"
        },{% endif %}
{% if neutron_plugin_agent in ['vmware_nsxv', 'vmware_nsxv3', 'vmware_nsxp', 'vmware_dvs'] -%}
        {
            "source": "{{ container_config_directory }}/nsx.ini",
            "dest": "/etc/neutron/plugins/vmware/nsx.ini",
            "owner": "neutron",
            "perm": "0600"
        },{% endif %}
{% if check_extra_ml2_plugins is defined and check_extra_ml2_plugins.matched > 0 %}{% for plugin in check_extra_ml2_plugins.files %}
        {
            "source": "{{ container_config_directory }}/{{ plugin.path | basename }}",
            "dest": "/etc/neutron/plugins/ml2/{{ plugin.path | basename }}",
            "owner": "neutron",
            "perm": "0600"
        },{% endfor %}{% endif %}
        {
            "source": "{{ container_config_directory }}/ml2_conf.ini",
            "dest": "/etc/neutron/plugins/ml2/ml2_conf.ini",
            "owner": "neutron",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/id_rsa",
            "dest": "/var/lib/neutron/.ssh/id_rsa",
            "owner": "neutron",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/neutron",
            "owner": "neutron:neutron",
            "recurse": true
        }
    ]
}
