#!/bin/bash

set -o errexit
set -o pipefail

keystone-manage --config-file /etc/keystone/keystone.conf fernet_rotate --keystone-user {{ keystone_username }} --keystone-group {{ keystone_groupname }}

/usr/bin/fernet-push.sh
