# Clear any old environment that may conflict.
for key in $( set | awk '{FS="="}  /^OS_/ {print $1}' ); do unset $key ; done
export OS_PROJECT_DOMAIN_NAME='Default'
export OS_USER_DOMAIN_NAME='Default'
export OS_PROJECT_NAME='{{ octavia_service_auth_project }}'
export OS_USERNAME='{{ octavia_keystone_user }}'
export OS_PASSWORD='{{ octavia_keystone_password }}'
export OS_AUTH_URL='{{ keystone_internal_url }}'
export OS_INTERFACE='internal'
export OS_ENDPOINT_TYPE='internalURL'
