{
    "command": "masakari-engine --config-file /etc/masakari/masakari.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/masakari.conf",
            "dest": "/etc/masakari/masakari.conf",
            "owner": "masakari",
            "perm": "0600"
        }{% if masakari_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ masakari_policy_file }}",
            "dest": "/etc/masakari/{{ masakari_policy_file }}",
            "owner": "masakari",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/lib/masakari",
            "owner": "masakari:masakari",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/masakari",
            "owner": "masakari:masakari",
            "recurse": true
        }
    ]
}
