{
    "command": "/usr/sbin/pacemaker_remoted -l /var/log/kolla/hacluster/pacemaker-remoted.log{% if openstack_logging_debug | bool %} -VV{% endif %} -p {{ hacluster_pacemaker_remote_port }}",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/authkey",
            "dest": "/etc/pacemaker/authkey",
            "owner": "root",
            "perm": "0400"
        }
    ]
}
