[ironic]
auth_url = {{ keystone_internal_url }}
auth_type = password
project_domain_id = {{ default_project_domain_id }}
user_domain_id = {{ default_user_domain_id }}
project_name = service
username = {{ ironic_keystone_user }}
password = {{ ironic_keystone_password }}
valid_interfaces = internal
region_name = {{ openstack_region_name }}
cafile = {{ openstack_cacert }}
