clouds:
  kolla-admin:
    auth:
      auth_url: {{ keystone_public_url }}
      project_domain_name: Default
      user_domain_name: Default
      project_name: {{ keystone_admin_project }}
      username: {{ keystone_admin_user }}
      password: {{ keystone_admin_password }}
    region_name: {{ openstack_region_name }}
{% if kolla_admin_openrc_cacert is not none and kolla_admin_openrc_cacert | length > 0 %}
    cacert: {{ kolla_admin_openrc_cacert }}
{% endif %}
  kolla-admin-internal:
    auth:
      auth_url: {{ keystone_internal_url }}
      project_domain_name: Default
      user_domain_name: Default
      project_name: {{ keystone_admin_project }}
      username: {{ keystone_admin_user }}
      password: {{ keystone_admin_password }}
    interface: internal
    region_name: {{ openstack_region_name }}
{% if kolla_admin_openrc_cacert is not none and kolla_admin_openrc_cacert | length > 0 %}
    cacert: {{ kolla_admin_openrc_cacert }}
{% endif %}
