{
    "command": "sleep infinity",
    "config_files": [
        {% if enable_rabbitmq | bool %}{
            "source": "{{ container_config_directory }}/rabbitmq-erlang.cookie",
            "dest": "/var/lib/rabbitmq/.erlang.cookie",
            "owner": "rabbitmq",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/rabbitmq-env.conf",
            "dest": "/etc/rabbitmq/rabbitmq-env.conf",
            "owner": "rabbitmq",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/erl_inetrc",
            "dest": "/etc/rabbitmq/erl_inetrc",
            "owner": "rabbitmq",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/ansible.log",
            "perm": "0664",
            "owner": "ansible:kolla"
        }
    ]
}
