{% set cron_cmd = 'cron -f' if kolla_base_distro in ['ubuntu', 'debian'] else 'crond -s -n' %}
{
    "command": "{{ cron_cmd }}",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/logrotate.conf",
            "dest": "/etc/logrotate.conf",
            "owner": "root",
            "perm": "0600"
        }
    ]
}
