{% set heat_log_dir = '/var/log/kolla/heat' %}
{% set binary_path = '/var/lib/kolla/venv/bin' %}
{% if heat_enable_tls_backend | bool %}
{% if kolla_base_distro in ['centos', 'rocky']  %}
LoadModule ssl_module /usr/lib64/httpd/modules/mod_ssl.so
{% else %}
LoadModule ssl_module /usr/lib/apache2/modules/mod_ssl.so
{% endif %}
{% endif %}
Listen {{ api_interface_address | put_address_in_context('url') }}:{{ heat_api_listen_port }}

ServerSignature Off
ServerTokens Prod
TraceEnable off
TimeOut {{ kolla_httpd_timeout }}
KeepAliveTimeout {{ kolla_httpd_keep_alive }}

<Directory "{{ binary_path }}">
    <FilesMatch "heat-wsgi-api">
        AllowOverride None
        Options None
        Require all granted
    </FilesMatch>
</Directory>

ErrorLog "{{ heat_log_dir }}/apache-error.log"
<IfModule log_config_module>
CustomLog "{{ heat_log_dir }}/apache-access.log" common
</IfModule>

<VirtualHost *:{{ heat_api_listen_port }}>
    WSGIDaemonProcess heat-api processes={{ heat_api_workers }} threads=1 user=heat group=heat display-name=heat-api
    WSGIProcessGroup heat-api
    WSGIScriptAlias / {{ binary_path }}/heat-wsgi-api
    WSGIApplicationGroup %{GLOBAL}
    WSGIPassAuthorization On
    <IfVersion >= 2.4>
      ErrorLogFormat "%{cu}t %M"
    </IfVersion>
    ErrorLog "{{ heat_log_dir }}/heat-api-error.log"
    LogFormat "%{X-Forwarded-For}i %l %u %t \"%r\" %>s %b %D \"%{Referer}i\" \"%{User-Agent}i\"" logformat
    CustomLog "{{ heat_log_dir }}/heat-api-access.log" logformat
{% if heat_enable_tls_backend | bool %}
    SSLEngine On
    SSLCertificateFile /etc/heat/certs/heat-cert.pem
    SSLCertificateKeyFile /etc/heat/certs/heat-key.pem
{% endif %}
</VirtualHost>
