# metadata_agent.ini
[DEFAULT]
auth_ca_cert = {{ openstack_cacert }}
nova_metadata_host = {{ nova_internal_fqdn }}
nova_metadata_port = {{ nova_metadata_port }}
metadata_proxy_shared_secret = {{ metadata_secret }}
nova_metadata_protocol = {{ internal_protocol }}
metadata_workers = {{ neutron_metadata_workers }}
