{
    "command": "/opt/prometheus-msteams -http-addr localhost:{{ prometheus_msteams_port }} -config-file /etc/msteams/msteams.yml -template-file /etc/msteams/msteams.tmpl",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/msteams.yml",
            "dest": "/etc/msteams/msteams.yml",
            "owner": "prometheus",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/msteams.tmpl",
            "dest": "/etc/msteams/msteams.tmpl",
            "owner": "prometheus",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/prometheus",
            "owner": "prometheus:kolla",
            "recurse": true
        }
    ]
}
