{
    "command": "{{ ovn_sb_command }}",
    "permissions": [
        {
            "path": "/var/log/kolla/openvswitch",
            "owner": "root:root",
            "recurse": true
        }
    ]
}
