{% set zun_log_dir = '/var/log/kolla/zun' %}
Listen {{ api_interface_address | put_address_in_context('url') }}:{{ zun_api_port }}

ServerSignature Off
ServerTokens Prod
TraceEnable off
TimeOut {{ kolla_httpd_timeout }}
KeepAliveTimeout {{ kolla_httpd_keep_alive }}

ErrorLog "{{ zun_log_dir }}/apache-error.log"
<IfModule log_config_module>
    CustomLog "{{ zun_log_dir }}/apache-access.log" common
</IfModule>

{% if zun_logging_debug | bool %}
LogLevel info
{% endif %}

<VirtualHost *:{{ zun_api_port }}>

  ## Vhost docroot
  DocumentRoot "/var/www/cgi-bin/zun"

  ## Directories, there should at least be a declaration for /var/www/cgi-bin/zun

  <Directory "/var/www/cgi-bin/zun">
    Options Indexes FollowSymLinks MultiViews
    AllowOverride None
    Require all granted
  </Directory>

  ## Logging
  ErrorLog "{{ zun_log_dir }}/zun_api_wsgi_error.log"
  ServerSignature Off
  LogFormat "%{X-Forwarded-For}i %l %u %t \"%r\" %>s %b %D \"%{Referer}i\" \"%{User-Agent}i\"" logformat
  CustomLog "{{ zun_log_dir }}/zun_api_wsgi_access.log" logformat
  WSGIApplicationGroup %{GLOBAL}
  WSGIDaemonProcess zun group=zun processes={{ zun_api_workers }} threads=1 user=zun
  WSGIProcessGroup zun
  WSGIScriptAlias / "/var/www/cgi-bin/zun/app.wsgi"
</VirtualHost>
