Listen {{ ironic_http_interface_address | put_address_in_context('url') }}:{{ ironic_http_port }}

TraceEnable off

<VirtualHost *:{{ ironic_http_port }}>
    LogLevel warn
    ErrorLog "/var/log/kolla/ironic/ironic-http-error.log"
    LogFormat "%h %l %u %t \"%r\" %>s %b %D \"%{Referer}i\" \"%{User-Agent}i\"" logformat
    CustomLog "/var/log/kolla/ironic/ironic-http-access.log" logformat
    DocumentRoot "/var/lib/ironic/httpboot"
    <Directory /var/lib/ironic/httpboot>
        Options FollowSymLinks
        AllowOverride None
        Require all granted
    </Directory>
</VirtualHost>
