[DEFAULT]
debug = {{ sahara_logging_debug }}
log_dir = /var/log/kolla/sahara
port = {{ sahara_api_port }}
host = {{ api_interface_address }}
transport_url = {{ rpc_transport_url }}

api_workers = {{ sahara_api_workers }}
use_floating_ips = False
use_namespaces = True
use_rootwrap = True

[database]
connection = mysql+pymysql://{{ sahara_database_user }}:{{ sahara_database_password }}@{{ sahara_database_address }}/{{ sahara_database_name }}
connection_recycle_time = {{ database_connection_recycle_time }}
max_pool_size = {{ database_max_pool_size }}

[keystone_authtoken]
service_type = data-processing
auth_url = {{ keystone_internal_url }}
auth_type = password
user_domain_name = {{ default_project_domain_name }}
project_name = service
project_domain_name = {{ default_project_domain_name }}
username = {{ sahara_keystone_user }}
password = {{ sahara_keystone_password }}
cafile = {{ openstack_cacert }}
region_name = {{ openstack_region_name }}

memcache_security_strategy = ENCRYPT
memcache_secret_key = {{ memcache_secret_key }}
memcached_servers = {% for host in groups['memcached'] %}{{ 'api' | kolla_address(host) | put_address_in_context('memcache') }}:{{ memcached_port }}{% if not loop.last %},{% endif %}{% endfor %}

[oslo_messaging_notifications]
transport_url = {{ notify_transport_url }}
{% if sahara_enabled_notification_topics %}
driver = messagingv2
topics = {{ sahara_enabled_notification_topics | map(attribute='name') | join(',') }}
{% else %}
driver = noop
{% endif %}

[oslo_messaging_rabbit]
heartbeat_in_pthread = false
{% if om_enable_rabbitmq_tls | bool %}
ssl = true
ssl_ca_file = {{ om_rabbitmq_cacert }}
{% endif %}
{% if om_enable_rabbitmq_high_availability | bool %}
amqp_durable_queues = true
{% endif %}

{% if sahara_policy_file is defined %}
[oslo_policy]
policy_file = {{ sahara_policy_file }}
{% endif %}


[profiler]
enabled = False

[trustee]
project_domain_name = {{ default_project_domain_name }}
project_name = service
user_domain_name = {{ default_user_domain_name }}
username = {{ sahara_keystone_user }}
password = {{ sahara_keystone_password }}
auth_url = {{ keystone_internal_url }}
cafile = {{ openstack_cacert }}
