[DEFAULT]
debug = {{ tacker_logging_debug }}
log_dir = /var/log/kolla/tacker

transport_url = {{ rpc_transport_url }}

bind_host = {{ api_interface_address }}
bind_port = {{ tacker_server_port }}
api_workers = {{ tacker_api_workers }}
service_plugins = nfvo,vnfm

[nfvo]
vim_drivers = openstack

[openstack_vim]
stack_retries = 60
stack_retry_wait = 10

{% if enable_barbican | bool %}
[vim_keys]
use_barbican = True
{% endif %}

[tacker]
monitor_driver = ping,http_ping
alarm_monitor_driver = ceilometer

[database]
connection = mysql+pymysql://{{ tacker_database_user }}:{{ tacker_database_password }}@{{ tacker_database_address }}/{{ tacker_database_name }}
connection_recycle_time = {{ database_connection_recycle_time }}
max_pool_size = {{ database_max_pool_size }}
max_retries = -1

[keystone_authtoken]
service_type = nfv-orchestration
www_authenticate_uri = {{ keystone_internal_url }}
auth_url = {{ keystone_internal_url }}
auth_type = password
project_domain_name = {{ default_project_domain_id }}
user_domain_name = {{ default_user_domain_id }}
project_name = service
username = {{ tacker_keystone_user }}
password = {{ tacker_keystone_password }}
cafile = {{ openstack_cacert }}
region_name = {{ openstack_region_name }}

memcache_security_strategy = ENCRYPT
memcache_secret_key = {{ memcache_secret_key }}
memcached_servers = {% for host in groups['memcached'] %}{{ 'api' | kolla_address(host) | put_address_in_context('memcache') }}:{{ memcached_port }}{% if not loop.last %},{% endif %}{% endfor %}

[alarm_auth]
username = {{ tacker_keystone_user }}
password = {{ tacker_keystone_password }}
project_name = service
url = {{ keystone_internal_url }}

[ceilometer]
host = {{ api_interface_address }}
port = {{ tacker_server_port }}


[oslo_messaging_notifications]
transport_url = {{ notify_transport_url }}
{% if tacker_enabled_notification_topics %}
driver = messagingv2
topics = {{ tacker_enabled_notification_topics | map(attribute='name') | join(',') }}
{% else %}
driver = noop
{% endif %}

[oslo_messaging_rabbit]
heartbeat_in_pthread = false
{% if om_enable_rabbitmq_tls | bool %}
ssl = true
ssl_ca_file = {{ om_rabbitmq_cacert }}
{% endif %}
{% if om_enable_rabbitmq_high_availability | bool %}
amqp_durable_queues = true
{% endif %}

{% if tacker_policy_file is defined %}
[oslo_policy]
policy_file = {{ tacker_policy_file }}
{% endif %}

[glance_store]
filesystem_store_datadir = /var/lib/tacker/csar_files
