{
    "command": "octavia-housekeeping --config-file /etc/octavia/octavia.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/octavia.conf",
            "dest": "/etc/octavia/octavia.conf",
            "owner": "octavia",
            "perm": "0600"
        }{% if 'amphora' in octavia_provider_drivers %},
        {
            "source": "{{ container_config_directory }}/client.cert-and-key.pem",
            "dest": "/etc/octavia/certs/client.cert-and-key.pem",
            "owner": "octavia",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/client_ca.cert.pem",
            "dest": "/etc/octavia/certs/client_ca.cert.pem",
            "owner": "octavia",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/server_ca.cert.pem",
            "dest": "/etc/octavia/certs/server_ca.cert.pem",
            "owner": "octavia",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/server_ca.key.pem",
            "dest": "/etc/octavia/certs/server_ca.key.pem",
            "owner": "octavia",
            "perm": "0600"
        }{% endif %}
    ]
}
