[keystone_authtoken]
# NOTE(yoctozepto): This is to avoid CRITICAL messages in logs
# when services try to contact Keystone when it is down due
# to upgrade running, seen especially in AIO jobs, where there
# is no backup to respond, most often with Placement, but also
# with Neutron and Nova.
http_request_max_retries = 9
