{
    "command": "venus-api --config-file /etc/venus/venus.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/venus.conf",
            "dest": "/etc/venus/venus.conf",
            "owner": "venus",
            "perm": "0644"
        }
    ],
   "permissions": [
        {
            "path":"/var/log/kolla/venus/venus-api.log",
            "owner": "venus:venus",
            "recurse": true
        }
    ]
}

