{
    "command": "/usr/sbin/corosync -f",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/corosync.conf",
            "dest": "/etc/corosync/corosync.conf",
            "owner": "root",
            "perm": "0400"
        },
        {
            "source": "{{ container_config_directory }}/authkey",
            "dest": "/etc/corosync/authkey",
            "owner": "root",
            "perm": "0400"
        }
    ]
}
