{
    "command": "/usr/sbin/haproxy -W -db -p /run/haproxy.pid -f /etc/glance/glance-tls-proxy.cfg",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/glance-tls-proxy.cfg",
            "dest": "/etc/glance/glance-tls-proxy.cfg",
            "owner": "glance",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/glance-cert-and-key.pem",
            "dest": "/etc/glance/certs/glance-cert-and-key.pem",
            "owner": "glance",
            "perm": "0600"
        }
    ]
}
