Port {{ nova_ssh_port }}
ListenAddress {{ api_interface_address }}
{% if migration_interface_address != api_interface_address %}
ListenAddress {{ migration_interface_address }}
{% endif %}

SyslogFacility AUTHPRIV
UsePAM yes
{% if kolla_base_distro in ["centos", "rocky"] %}
Subsystem       sftp    /usr/libexec/openssh/sftp-server
{% endif %}
