[defaults]
callback_plugins = {{ ara_callback_plugins.stdout }}
host_key_checking = False
# Ensure that facts are referenced via ansible_facts.<fact>.
inject_facts_as_vars = False

[ssh_connection]
pipelining = True
retries = 3
