[DEFAULT]
debug = {{ blazar_logging_debug }}
log_dir = /var/log/kolla/blazar
transport_url = {{ rpc_transport_url }}
host = {{ api_interface_address }}
port = {{ blazar_api_port }}
os_auth_host = {{ keystone_internal_fqdn }}
os_auth_port = {{ keystone_public_port }}
os_auth_protocol = {{ internal_protocol }}
os_admin_username = {{ blazar_keystone_user }}
os_admin_password = {{ blazar_keystone_password }}
os_admin_project_name = service
identity_service = identity

[api]
api_v2_controllers = oshosts,leases

[manager]
plugins = virtual.instance.plugin,physical.host.plugin

[keystone_authtoken]
service_type = reservation
www_authenticate_uri = {{ keystone_internal_url }}
auth_url = {{ keystone_internal_url }}
auth_type = password
project_domain_id = default
user_domain_id = default
project_name = service
username = {{ blazar_keystone_user }}
password = {{ blazar_keystone_password }}
service_token_roles_required = True
cafile = {{ openstack_cacert }}
region_name = {{ openstack_region_name }}

memcache_security_strategy = ENCRYPT
memcache_secret_key = {{ memcache_secret_key }}
memcached_servers = {% for host in groups['memcached'] %}{{ 'api' | kolla_address(host) | put_address_in_context('memcache') }}:{{ memcached_port }}{% if not loop.last %},{% endif %}{% endfor %}

[database]
connection = mysql+pymysql://{{ blazar_database_user }}:{{ blazar_database_password }}@{{ blazar_database_address }}/{{ blazar_database_name }}
connection_recycle_time = {{ database_connection_recycle_time }}
max_pool_size = {{ database_max_pool_size }}
max_retries = -1

[nova]
aggregate_freepool_name = {{ blazar_aggregate_pool_name }}

[oslo_messaging_notifications]
{% if blazar_enabled_notification_topics %}
driver = messagingv2
topics = {{ blazar_enabled_notification_topics | map(attribute='name') | join(',') }}
{% else %}
driver = noop
{% endif %}

[oslo_messaging_rabbit]
heartbeat_in_pthread = false
{% if om_enable_rabbitmq_tls | bool %}
ssl = true
ssl_ca_file = {{ om_rabbitmq_cacert }}
{% endif %}
{% if om_enable_rabbitmq_high_availability | bool %}
amqp_durable_queues = true
{% endif %}

{% if blazar_policy_file is defined %}
[oslo_policy]
policy_file = {{ blazar_policy_file }}
{% endif %}
