[DEFAULT]
debug = {{ masakari_logging_debug }}
log_dir = /var/log/kolla/masakari

[api]
region = {{ openstack_region_name }}
auth_url = {{ keystone_internal_url }}
user_domain_id = {{ default_user_domain_id }}
project_name = service
project_domain_id = {{ default_project_domain_id }}
username = {{ masakari_keystone_user }}
password = {{ masakari_keystone_password }}
cafile = {{ openstack_cacert }}
api_interface = internal

{% if service_name == 'masakari-instancemonitor' %}
[libvirt]
connection_uri = "qemu+tcp://{{ migration_interface_address | put_address_in_context('url') }}/system"
{% endif %}

{% if service_name == 'masakari-hostmonitor' %}
[host]
{#
  NOTE(yoctozepto): ``restrict_to_remotes`` is due to being unable to monitor
  both types at once and Kolla has remotes on dedicated computes so it is
  a better default choice.
  This limitation may be lifted in the near future (Xena+).
#}
restrict_to_remotes = True
{#
  NOTE(yoctozepto): ``disable_ipmi_check`` is due to ``restrict_to_remotes``
  above.
  See https://bugs.launchpad.net/masakari-monitors/+bug/1933203
#}
disable_ipmi_check = True
{% if inventory_hostname in groups['hacluster'] %}
pacemaker_node_type = cluster
corosync_multicast_interfaces = {{ api_interface }}
corosync_multicast_ports = {{ hacluster_corosync_port }}
{% elif inventory_hostname in groups['hacluster-remote'] %}
pacemaker_node_type = remote
{% endif %}
{% endif %}
