<source>
  @type tail
  path /var/log/kolla/rabbitmq/rabbit@{{ ansible_facts.hostname }}.log
  pos_file /var/run/td-agent/rabbit.pos
  tag infra.rabbit
  enable_watch_timer false
  <parse>
    @type multiline
    format_firstline /^\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}\.\d{3}/
    format1 /^(?<Timestamp>\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}\.\d{3}) \[(?<log_level>\w+)\] (?<Payload>.*)/
  </parse>
</source>
