{% set masakari_log_dir = '/var/log/kolla/masakari' %}
{% set binary_path = '/var/lib/kolla/venv/bin' %}

Listen {{ api_interface_address | put_address_in_context('url') }}:{{ masakari_api_port }}

ServerSignature Off
ServerTokens Prod
TraceEnable off
TimeOut {{ kolla_httpd_timeout }}
KeepAliveTimeout {{ kolla_httpd_keep_alive }}

ErrorLog "{{ masakari_log_dir }}/apache-error.log"
<IfModule log_config_module>
    CustomLog "{{ masakari_log_dir }}/apache-access.log" common
</IfModule>

{% if masakari_logging_debug | bool %}
LogLevel info
{% endif %}

<Directory "{{ binary_path }}">
    <FilesMatch "^masakari-wsgi$">
      Options Indexes FollowSymLinks MultiViews
      Require all granted
    </FilesMatch>
</Directory>

<VirtualHost *:{{ masakari_api_port }}>
  ## Logging
  ErrorLog "{{ masakari_log_dir }}/masakari_wsgi_error.log"
  LogFormat "%{X-Forwarded-For}i %l %u %t \"%r\" %>s %b %D \"%{Referer}i\" \"%{User-Agent}i\"" logformat
  CustomLog "{{ masakari_log_dir }}/masakari_wsgi_access.log" logformat
  WSGIApplicationGroup %{GLOBAL}
  WSGIDaemonProcess masakari group=masakari processes={{ masakari_api_workers }} threads=1 user=masakari
  WSGIProcessGroup masakari
  WSGIScriptAlias / "{{ binary_path }}/masakari-wsgi"
</VirtualHost>
