[libvirt]
{% if libvirt_tls | bool %}
connection_uri = "qemu+tls://{{ migration_hostname | put_address_in_context('url') }}/system"
live_migration_scheme = "tls"
live_migration_inbound_addr = "{{ migration_hostname }}"
{% else %}
connection_uri = "qemu+tcp://{{ migration_interface_address | put_address_in_context('url') }}/system"
live_migration_inbound_addr = "{{ migration_interface_address }}"
{% endif %}
{% if nova_backend == "rbd" %}
images_type = rbd
images_rbd_pool = {{ ceph_nova_pool_name }}
images_rbd_ceph_conf = /etc/ceph/ceph.conf
rbd_user = {{ ceph_nova_user }}
disk_cachemodes="network=writeback"
{% if nova_hw_disk_discard != '' %}
hw_disk_discard = {{ nova_hw_disk_discard }}
{% endif %}
{% endif %}
{% if nova_backend == "rbd" and external_ceph_cephx_enabled | bool %}
rbd_secret_uuid = {{ rbd_secret_uuid }}
{% endif %}
virt_type = {{ nova_compute_virt_type }}
{% if nova_libvirt_cpu_mode %}
cpu_mode = {{ nova_libvirt_cpu_mode }}
{% endif %}
{% if enable_multipathd | bool %}
volume_use_multipath = True
{% endif %}
num_pcie_ports = 16
[workarounds]
skip_cpu_compare_on_dest = True
