<source>
  @type prometheus
  bind {{ api_interface_address }}
  port {{ prometheus_fluentd_integration_port }}
  metrics_path /metrics
</source>

<source>
  @type prometheus_output_monitor
  interval 10
  <labels>
    Hostname ${hostname}
  </labels>
</source>
