{
    "command": "cinder-backup --config-file /etc/cinder/cinder.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/cinder.conf",
            "dest": "/etc/cinder/cinder.conf",
            "owner": "cinder",
            "perm": "0600"
        }{% if cinder_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ cinder_policy_file }}",
            "dest": "/etc/cinder/{{ cinder_policy_file }}",
            "owner": "cinder",
            "perm": "0600"
        }{% endif %}{% if cinder_backend_ceph | bool %},
        {
            "source": "{{ container_config_directory }}/ceph.conf",
            "dest": "/etc/ceph/ceph.conf",
            "owner": "cinder",
            "perm": "0600",
            "optional": {{ (not cinder_backend_ceph | bool) | string | lower }}
        },
        {
            "source": "{{ container_config_directory }}/{{ ceph_cinder_keyring }}",
            "dest": "/etc/ceph/{{ ceph_cinder_keyring }}",
            "owner": "cinder",
            "perm": "0600",
            "optional": {{ (not cinder_backend_ceph | bool) | string | lower }}
        },
        {
            "source": "{{ container_config_directory }}/{{ ceph_cinder_backup_keyring }}",
            "dest": "/etc/ceph/{{ ceph_cinder_backup_keyring }}",
            "owner": "cinder",
            "perm": "0600",
            "optional": {{ (not cinder_backend_ceph | bool) | string | lower }}
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/lib/cinder",
            "owner": "cinder:cinder",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/cinder",
            "owner": "cinder:cinder",
            "recurse": true
        }
    ]
}
