{% set aodh_log_dir = '/var/log/kolla/aodh' %}
{% set binary_path = '/var/lib/kolla/venv/bin' %}
Listen {{ api_interface_address | put_address_in_context('url') }}:{{ aodh_api_listen_port }}

ServerSignature Off
ServerTokens Prod
TraceEnable off
TimeOut {{ kolla_httpd_timeout }}
KeepAliveTimeout {{ kolla_httpd_keep_alive }}

ErrorLog "{{ aodh_log_dir }}/apache-error.log"
<IfModule log_config_module>
    CustomLog "{{ aodh_log_dir }}/apache-access.log" common
</IfModule>

{% if aodh_logging_debug | bool %}
LogLevel info
{% endif %}

<Directory "{{ binary_path }}">
    <FilesMatch "^aodh-api$">
      Options Indexes FollowSymLinks MultiViews
      AllowOverride None
      Require all granted
    </FilesMatch>
</Directory>

<VirtualHost *:{{ aodh_api_listen_port }}>
  ## Logging
  ErrorLog "{{ aodh_log_dir }}/aodh_wsgi_error.log"
  ServerSignature Off
  LogFormat "%{X-Forwarded-For}i %l %u %t \"%r\" %>s %b %D \"%{Referer}i\" \"%{User-Agent}i\"" logformat
  CustomLog "{{ aodh_log_dir }}/aodh_wsgi_access.log" logformat
  WSGIApplicationGroup %{GLOBAL}
  WSGIDaemonProcess aodh group=aodh processes={{ aodh_api_workers }} threads=1 user=aodh
  WSGIProcessGroup aodh
  WSGIScriptAlias / "{{ binary_path }}/aodh-api"
</VirtualHost>
