[uwsgi]
{% if barbican_enable_tls_backend | bool %}
https-socket = {{ api_interface_address | put_address_in_context('url') }}:{{ barbican_api_listen_port }},/etc/barbican/certs/barbican-cert.pem,/etc/barbican/certs/barbican-key.pem
{% else %}
http-socket = {{ api_interface_address | put_address_in_context('url') }}:{{ barbican_api_listen_port }}
{% endif %}
processes = {{ barbican_api_workers }}
lazy = true
vacuum = true
no-default-app = true
memory-report = true
plugins = python3
paste = config:/etc/barbican/barbican-api-paste.ini
add-header = Connection: close
logto = /var/log/kolla/barbican/barbican_api_uwsgi_access.log
