{
    "command": "/usr/share/opensearch/bin/opensearch",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/opensearch.yml",
            "dest": "/etc/opensearch/opensearch.yml",
            "owner": "opensearch",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/lib/opensearch",
            "owner": "opensearch:opensearch",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/opensearch",
            "owner": "opensearch:opensearch",
            "recurse": true
        }
    ]
}
