{
    "command": "cloudkitty-processor --config-file /etc/cloudkitty/cloudkitty.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/cloudkitty.conf",
            "dest": "/etc/cloudkitty/cloudkitty.conf",
            "owner": "cloudkitty",
            "perm": "0600"
        }{% if cloudkitty_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ cloudkitty_policy_file }}",
            "dest": "/etc/cloudkitty/{{ cloudkitty_policy_file }}",
            "owner": "cloudkitty",
            "perm": "0600"
        }{% endif %}{% if cloudkitty_custom_metrics_used %},
        {
            "source": "{{ container_config_directory }}/{{ cloudkitty_custom_metrics_yaml_file }}",
            "dest": "/etc/cloudkitty/{{ cloudkitty_custom_metrics_yaml_file }}",
            "owner": "cloudkitty",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/cloudkitty",
            "owner": "cloudkitty:cloudkitty",
            "recurse": true
        }
    ]
}
