{
    "command": "/usr/bin/ovn-controller --pidfile=/run/ovn/ovn-controller.pid --log-file=/var/log/kolla/openvswitch/ovn-controller.log tcp:127.0.0.1:{{ ovsdb_port }}",
    "permissions": [
        {
            "path": "/var/log/kolla/openvswitch",
            "owner": "root:root",
            "recurse": true
        }
    ]
}
