{
    "command": "masakari-instancemonitor --config-file /etc/masakari-monitors/masakari-monitors.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/masakari-monitors.conf",
            "dest": "/etc/masakari-monitors/masakari-monitors.conf",
            "owner": "masakari",
            "perm": "0600"
        }{% if libvirt_enable_sasl | bool %},
        {
            "source": "{{ container_config_directory }}/auth.conf",
            "dest": "/var/lib/masakari/.config/libvirt/auth.conf",
            "owner": "masakari",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/masakari",
            "owner": "masakari:masakari",
            "recurse": true
        }
    ]
}
