{
    "command": "nova-compute",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/nova.conf",
            "dest": "/etc/nova/nova.conf",
            "owner": "nova",
            "perm": "0600"
        }{% if nova_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ nova_policy_file }}",
            "dest": "/etc/nova/{{ nova_policy_file }}",
            "owner": "nova",
            "perm": "0600"
        }{% endif %}{% if nova_backend == "rbd" %},
        {
            "source": "{{ container_config_directory }}/{{ ceph_nova_keyring }}",
            "dest": "/etc/ceph/{{ ceph_nova_keyring }}",
            "owner": "nova",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/ceph.conf",
            "dest": "/etc/ceph/ceph.conf",
            "owner": "nova",
            "perm": "0600"
        }{% endif %}{% if nova_compute_virt_type == "vmware" and not vmware_vcenter_insecure | bool %},
        {
            "source": "{{ container_config_directory }}/vmware_ca",
            "dest": "/etc/nova/vmware_ca",
            "owner": "nova",
            "perm": "0600"
        }{% endif %}{% if libvirt_tls | bool %},
        {
            "source": "{{ container_config_directory }}/clientkey.pem",
            "dest": "/etc/pki/libvirt/private/clientkey.pem",
            "owner": "root:nova",
            "perm": "0640"
        },
        {
            "source": "{{ container_config_directory }}/clientcert.pem",
            "dest": "/etc/pki/libvirt/clientcert.pem",
            "owner": "root:nova",
            "perm": "0640"
        },
        {
            "source": "{{ container_config_directory }}/cacert.pem",
            "dest": "/etc/pki/CA/cacert.pem",
            "owner": "root:nova",
            "perm": "0640"
        }{% endif %},
        {
            "source": "{{ container_config_directory }}/release",
            "dest": "/etc/nova/release",
            "owner": "nova",
            "perm": "0600",
            "optional": true
        }{% if nova_compute_virt_type in ['kvm', 'qemu'] and libvirt_enable_sasl | bool %},
        {
            "source": "{{ container_config_directory }}/auth.conf",
            "dest": "/var/lib/nova/.config/libvirt/auth.conf",
            "owner": "nova",
            "perm": "0600"
        }{% endif %}{% if nova_cell_compute_provider_config is defined %},
        {
            "source": "{{ container_config_directory }}/provider_config.yaml",
            "dest": "/etc/nova/provider_config/provider_config.yaml",
            "owner": "nova",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/nova",
            "owner": "nova:nova",
            "recurse": true
        },
        {
            "path": "/var/lib/nova",
            "owner": "nova:nova",
            "recurse": true
        }
    ]
}
