{
    "command": "/opt/blackbox_exporter/blackbox_exporter --config.file=/etc/prometheus/blackbox.yml --web.listen-address={{ api_interface_address | put_address_in_context('url') }}:{{ prometheus_blackbox_exporter_port }} --log.level=info{% if prometheus_blackbox_exporter_cmdline_extras %} {{ prometheus_blackbox_exporter_cmdline_extras }}{% endif %}",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/prometheus-blackbox-exporter.yml",
            "dest": "/etc/prometheus/blackbox.yml",
            "owner": "prometheus",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/prometheus",
            "owner": "prometheus:kolla",
            "recurse": true
        }
    ]
}
