{
    "command": "/etc/proxysql_run.sh",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/proxysql_run.sh",
            "dest": "/etc/proxysql_run.sh",
            "owner": "proxysql",
            "perm": "0700"
        },
        {
            "source": "{{ container_config_directory }}/proxysql.yaml",
            "dest": "/etc/proxysql/proxysql.yaml",
            "owner": "proxysql",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/users/",
            "dest": "/etc/proxysql/users",
            "owner": "proxysql",
            "perm": "0700"
        },
        {
            "source": "{{ container_config_directory }}/rules/",
            "dest": "/etc/proxysql/rules",
            "owner": "proxysql",
            "perm": "0700"
        }
    ]
}
