{
    "command": "etcd",
    "config_files": [
        {% if etcd_enable_tls | bool %}
        {
            "source": "{{ container_config_directory }}/etcd-cert.pem",
            "dest": "/etc/etcd/certs/etcd-cert.pem",
            "owner": "etcd",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/etcd-key.pem",
            "dest": "/etc/etcd/certs/etcd-key.pem",
            "owner": "etcd",
            "perm": "0600"
        }{% endif %}
    ]
}
