[DEFAULT]
auth_ca_cert = {{ openstack_cacert }}
nova_metadata_protocol = {{ internal_protocol }}
metadata_proxy_socket = /var/lib/neutron/kolla/metadata_proxy
nova_metadata_host = {{ nova_internal_fqdn }}
nova_metadata_port = {{ nova_metadata_port }}
metadata_proxy_shared_secret = {{ metadata_secret }}
log_file = neutron-ovn-metadata-agent.log
log_dir = /var/log/kolla/neutron
metadata_workers = 2

[ovs]
ovsdb_connection = tcp:127.0.0.1:{{ ovsdb_port }}
ovsdb_timeout = {{ ovsdb_timeout }}

[ovn]
ovn_nb_connection = {{ ovn_nb_connection }}
ovn_sb_connection = {{ ovn_sb_connection }}
ovn_metadata_enabled = true
